@@ -1,3 +1,5 @@
+from typing import Dict
+
 from sym.cli.data.ansible_options import AnsibleOptions
 from sym.cli.data.target_options import TargetOptions
 from sym.cli.helpers.global_options import GlobalOptions
@@ -17,7 +19,7 @@ class RequestData:
         global_options: GlobalOptions = None,
         target_options: TargetOptions = None,
         ansible_options: AnsibleOptions = None,
-        params: {} = None,
+        params: Dict = None,
     ):
         self.action = action
         self.resource = resource
