@@ -292,10 +292,7 @@ def ensure_ssh_key(
     ensure_public_key_on_instance(client, instance, port, args=args)
 
 
-def start_tunnel(client, instance: str, port: int):
-    SymGroup.reset_tees()
-    client.dprint("execing aws ssm")
-
+def _handler_factory(instance):
     def handler(signum, frame):
         devnull = os.open(os.devnull, os.O_WRONLY)
         os.dup2(devnull, sys.stdout.fileno())
@@ -306,27 +303,22 @@ def start_tunnel(client, instance: str, port: int):
         # loops with Ansible due to missing SSH public keys.
         Config.touch_instance(instance, error=True)
 
-    signal(SIGPIPE, handler)
+    return handler
+
+
+def start_tunnel(client, instance: str, port: int):
+    client.dprint("execing aws ssm")
+    SymGroup.reset_tees()
+    signal(SIGPIPE, _handler_factory(instance))
 
     with ssm_ssh_session(client, instance, port) as command:
         client.exec(*command, suppress_=True)
 
 
 def start_interactive_command(client, instance: str, command: Sequence[str]):
-    SymGroup.reset_tees()
     client.dprint("execing aws ssm interactive command")
-
-    def handler(signum, frame):
-        devnull = os.open(os.devnull, os.O_WRONLY)
-        os.dup2(devnull, sys.stdout.fileno())
-        # Set error state on session end.
-        # If the connection was actually successful,
-        # the parent thread will re-set a success state.
-        # This is the only reliable way to avoid error
-        # loops with Ansible due to missing SSH public keys.
-        Config.touch_instance(instance, error=True)
-
-    signal(SIGPIPE, handler)
+    SymGroup.reset_tees()
+    signal(SIGPIPE, _handler_factory(instance))
 
     with ssm_interactive_command(client, instance, get_ssh_user(), command) as command:
         client.exec(*command, suppress_=True)
